'use client'

import useGallery from "@/feature/messenger/hooks/useGallery"
import { formatFileSize } from "@/feature/messenger/utils/FileSizeFormat";
import { useTranslation } from "@/hooks/useTranslation";
import { Button, Dropdown, DropdownItem, DropdownMenu, DropdownTrigger, Listbox, ListboxItem, Modal, ModalBody, ModalContent, ModalFooter, ModalHeader } from "@nextui-org/react";
import { File, MoreVertical } from "react-feather";

const Gallery = () => {

    const { trans } = useTranslation();
    const {
        openModalGallery,
        openConfirm,
        openDropdown,
        toggleConfirm,
        toggleGallery,
        toggleDropdown,
        loading,
        resources,
        listGallery,
        confimSendGallery,
        showResourcesByCategory,
        hideListResources,
        toggleConfirmClose
    } = useGallery();

    const centered = true;

    const handleFileOpen = (e: React.MouseEvent, url: string) => {
        e.preventDefault();
        window.open(url, '_blank');
    };

    return (
        <>
            <Modal
                isOpen={openModalGallery}
                onOpenChange={() => toggleGallery()}
                size="lg"
            >
                <ModalContent>
                    {(onClose) => (
                        <>
                            <ModalHeader>
                                {trans("modal_conversations_galery_title")}
                            </ModalHeader>
                            <ModalBody className="pb-4">

                                <div className="container mb-2">
                                    <div className="">
                                        <div className="">
                                            <Button color="warning" size="sm" onClick={() => hideListResources()} style={{ display: resources.length !== 0 ? 'block' : 'none', padding: '5px 15px' }}>{trans("modal_conversations_galery_back_button_title")}</Button>
                                        </div>
                                    </div>
                                </div>

                                <div className="container">
                                    {resources.length == 0 && (
                                        <div>
                                            <h3 className="text-center p-2 mb-3 font-semibold">{trans("modal_conversations_galery_subtitle_category")}</h3>
                                            <Listbox
                                                aria-label="User Menu"
                                                className="p-0 gap-0 divide-y divide-default-300/50 dark:divide-default-100/80 bg-content1 w-full overflow-visible shadow-small rounded-medium max-h-[350px] overflow-y-auto overflow-x-hidden"
                                                itemClasses={{
                                                    base: "px-3 first:rounded-t-medium last:rounded-b-medium rounded-none gap-3 h-12 data-[hover=true]:bg-default-100/80",
                                                }}
                                            >
                                                {listGallery.map((item: any, index: any) => (
                                                    <ListboxItem
                                                        key="issues"
                                                        endContent={
                                                            <Dropdown placement="top">
                                                                <DropdownTrigger>
                                                                    <Button color="primary" radius="full" className="min-w-11 min-h-11 size-11 p-0" variant="flat">
                                                                        <MoreVertical size={22} />
                                                                    </Button>
                                                                </DropdownTrigger>
                                                                <DropdownMenu aria-label="Dynamic Actions">
                                                                    <DropdownItem key="Ver recursos" onClick={() => showResourcesByCategory(item.resources)}>
                                                                        {trans("modal_conversations_galery_show_resources_title")}
                                                                    </DropdownItem>
                                                                </DropdownMenu>
                                                            </Dropdown>
                                                        }
                                                        startContent={
                                                            <File size={22} />
                                                        }
                                                    >
                                                        <strong>{item.categoria}</strong>
                                                    </ListboxItem>
                                                ))}
                                            </Listbox>
                                        </div>
                                    )}
                                    {resources.length > 0 && (
                                        <div>
                                            <h3 className="text-center p-2 mb-3 font-semibold">{trans("modal_conversations_galery_resources_subtitle")}</h3>
                                            <Listbox
                                                aria-label="User Menu"
                                                className="p-0 gap-0 divide-y divide-default-300/50 dark:divide-default-100/80 bg-content1 w-full overflow-visible shadow-small rounded-medium max-h-[350px] overflow-y-auto overflow-x-hidden"
                                                itemClasses={{
                                                    base: "px-3 first:rounded-t-medium last:rounded-b-medium rounded-none gap-3 h-12 data-[hover=true]:bg-default-100/80",
                                                }}
                                            >
                                                {resources.map((item: any, index: any) => (
                                                    <ListboxItem
                                                        key="issues"
                                                        endContent={
                                                            <Dropdown placement="top">
                                                                <DropdownTrigger>
                                                                    <Button color="primary" radius="full" className="min-w-11 min-h-11 size-11 p-0" variant="flat">
                                                                        <MoreVertical size={22} />
                                                                    </Button>
                                                                </DropdownTrigger>
                                                                <DropdownMenu aria-label="Dynamic Actions">
                                                                    <DropdownItem 
                                                                        key="Ver recursos" 
                                                                        onPress={() => window.open(item.url, '_blank')}
                                                                    >
                                                                        {trans("modal_conversations_galery_show_files_title")}
                                                                    </DropdownItem>
                                                                    <DropdownItem key="Ver recursos" onClick={() => toggleConfirm(item.url)}>
                                                                        {trans("modal_conversations_galery_send_files_title")}
                                                                    </DropdownItem>
                                                                </DropdownMenu>
                                                            </Dropdown>
                                                        }
                                                        startContent={
                                                            <File size={22} />
                                                        }
                                                    >
                                                        <div className="ms-2 me-auto">
                                                            <div className="fw-bold">
                                                                <strong>{item.archivo}</strong>
                                                            </div>
                                                            <small>{item.fecha} | {formatFileSize(parseInt(item.size))}</small>
                                                        </div>
                                                    </ListboxItem>
                                                ))}
                                            </Listbox>
                                        </div>
                                    )}
                                </div>
                            </ModalBody>
                        </>
                    )}
                </ModalContent>
            </Modal >

            {/* Modal Confirm */}
            <Modal
                isOpen={openConfirm}
                onOpenChange={() => toggleConfirmClose}
            >
                <ModalContent>
                    {(onClose) => (
                        <>
                            <ModalBody>
                                <div>
                                    <div>
                                        <h3 className="text-center font-semibold">{trans("modal_conversations_galery_confirm_send_files_title")}</h3>
                                    </div>
                                    <ModalFooter className="flex justify-around items-center">
                                        <Button color="danger" isDisabled={loading} onPress={toggleConfirmClose}>
                                            {trans("modal_conversations_galery_confirm_button_cancel")}
                                        </Button>
                                        <Button color="primary" isLoading={loading} type="button" onClick={() => confimSendGallery()}>
                                            {loading ? trans("modal_conversations_galery_confirm_button_send_loading") : trans("modal_conversations_galery_send_files_title")}
                                        </Button>
                                    </ModalFooter>
                                </div>
                            </ModalBody>
                        </>
                    )}
                </ModalContent>
            </Modal>
        </>
    )
}

export default Gallery